<?php

namespace App\Console\Commands;

use App\Jobs\CheckReportStatus;
use App\Models\AmazonOauthToken;
use App\Models\ReportRequest;
use App\Services\AmazonAdsService;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Auth;
use SebastianBergmann\CodeCoverage\Report\Xml\Report;

class GenerateReport extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'report:generate';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command to generate amazon ads campaign daily performance report';

    /**
     * Execute the console command.
     */
    public function handle()
    {
        //
        $amazonAdsService = new AmazonAdsService();
        $accounts=AmazonOauthToken::get();
        foreach($accounts as $account){
            $access_token=$amazonAdsService->getAccessToken($account->refresh_token);
            $reportdata=$amazonAdsService->getCampaignPerformanceData($access_token,$account->selling_partner_id);
            $request=ReportRequest::create([
                'report_id' => $reportdata['reportId'],
                'status' => 'PENDING',
                'requested_at' => now(),
                'auth_token_id' => $account->id,
            ]);

            CheckReportStatus::dispatch($request->id)->delay(now()->addMinutes(15));
        }
        echo 'Command executed successfully';
    }
}
