<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Contracts\View\View;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\ValidationException;

class LoginController extends Controller
{
    public function login()
    {
        // return view('pages.login');
        // return view('livewire.pages.auth.login');
        return redirect('/login');
    }

    public function submit(Request $request)
    {
        $request->validate([
            'email' => 'required|exists:users,email',
            'password' => 'required',
        ]);
        $user = User::where('email', $request->email)->first();
        if (! $user->hasRole('super admin')) {
            throw ValidationException::withMessages(['email' => 'Only admin can login here.']);
        }
        if (! Hash::check($request->password, $user->password)) {
            throw ValidationException::withMessages(['email' => 'Credential not match.']);
        }
        try {
            if (Auth::attempt(['email' => $request->email, 'password' => $request->password])) {
                return redirect()->to(route('admin.dashboard'));
            }
        } catch (\Throwable $th) {
            return redirect()->back();
        }
    }
}
