<?php

namespace App\Http\Controllers;

use App\Models\AdGroup;
use App\Models\AmazonOauthToken;
use App\Models\CampaignPerformanceMetric;
use App\Models\ConnectedAccount;
use App\Models\Ebay_Campaigns;
use Illuminate\Http\Request;
use App\Services\AmazonAdsService;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Storage;

class AmazonAdsController extends Controller
{
    //
     protected $amazonAdsService;

    public function __construct(AmazonAdsService $amazonAdsService)
    {
        $this->amazonAdsService = $amazonAdsService;
    }

    /**
     * Redirect User to Amazon Login for Authorization
     */
    public function redirectToAmazon()
    {
        return redirect($this->amazonAdsService->getAuthorizationUrl());
    }

    /**
     * Handle Amazon OAuth Callback and Store Refresh Token
     */
    public function handleAmazonCallback(Request $request)
    {
        $authorizationCode = $request->query('code');

        if (!$authorizationCode) {
            return response()->json(['error' => 'Authorization code is missing'], 400);
        }

        $refreshToken = $this->amazonAdsService->getRefreshToken($authorizationCode);
        if ($refreshToken) {
            file_put_contents(base_path('.env'), str_replace(
                'AMAZON_REFRESH_TOKEN=null',
                "AMAZON_REFRESH_TOKEN=$refreshToken",
                file_get_contents(base_path('.env'))
            ));
            return response()->json(['message' => 'Refresh Token saved successfully']);
        }

        return response()->json(['error' => 'Failed to get refresh token'], 500);
    }

    /**
     * List Ad Campaigns
     */
    public function listCampaigns(Request $request)
    {
        $account=AmazonOauthToken::where('user_id',Auth::user()->id)->first();
        $access_token=$this->amazonAdsService->getAccessToken($account->refresh_token);
        $campaignsResponse =$this->amazonAdsService->getCampaigns($access_token,$account->selling_partner_id);
        if (!isset($campaignsResponse['campaigns']) || empty($campaignsResponse['campaigns'])) {
            return response()->json(['message' => 'No campaigns found'], 200);
        }
        foreach ($campaignsResponse['campaigns'] as $campaign) {
            // Map API response to database columns
            $campaignData = [
                'campaign_id'             => $campaign['campaignId'] ?? null,
                'campaign_name'           => $campaign['name'] ?? null,
                'marketplace_id'          => $account->marketplace_id ?? null, // Assuming it's linked to account
                'campaign_status'         => $campaign['state'] ?? null,
                'start_date'              => $campaign['startDate'] ?? null,
                'end_date'                => $campaign['endDate'] ?? null,
                'campaign_targeting_type' => $campaign['targetingType'] ?? null,
                'funding_model'           => $campaign['budget']['budgetType'] ?? null,
                'bidding_strategy'        => $campaign['dynamicBidding']['strategy'] ?? null,
                'daily_budget_value'      => $campaign['budget']['budget'] ?? null,
                'daily_budget_currency'   => 'USD', // Assuming USD (you can update accordingly)
                'daily_budget_status'     => 'ACTIVE', // You can modify based on business logic
                'channels'                => json_encode($campaign['offAmazonSettings'] ?? []), // Storing as JSON if needed
                'source'                  => 'Amazon', // Assuming campaigns are from Amazon
            ];

            // Store campaign in the database (Insert or Update)
            Ebay_Campaigns::updateOrCreate(
                ['campaign_id' => $campaignData['campaign_id']], // Unique constraint
                $campaignData
            );
        }
        return redirect()->route('Ebay.Campaigns');
    }

    public function handleCallback(Request $request)
    {
        // Log::info('Code came in handleCallback'.$request);
        if ($request->has('code')) {
            $code = $request->get('code');
        
        // Get the refresh token from your service
        $refresh_token = $this->amazonAdsService->getRefreshToken($code);

        // Get the access token from your service
        $accessToken = $this->amazonAdsService->getAccessToken($refresh_token);

        // Get the selling partner ID (this should be returned by the API or another service)
        $selling_partner_id = $this->amazonAdsService->getProfileId($accessToken);

        // Get the region (you might already have it in your request or session)
        $region = $request->get('region', 'us'); // Default to 'us' if not provided

        // Assuming 'user_id' is available, e.g., from session or request
        $userId = auth()->id(); // For authenticated users, else provide a default user_id

        // Get the expiry time for the access token (set a default expiry)
        $access_token_expiry = now()->addHours(1); // Example: 1 hour from now

        // Save the token data, including the selling_partner_id, to the database
        $tokenData = AmazonOauthToken::updateOrCreate(
            ['user_id' => $userId, 'marketplace_id' => 'amazon', 'region' => $region],
            [
                'access_token' => $accessToken,
                'refresh_token' => $refresh_token,
                'access_token_expiry' => $access_token_expiry,
                'selling_partner_id' => $selling_partner_id, // Store the selling partner ID
            ]
        );
        return redirect()->route('channels.creat');
        }
    }
    public function test(Request $request){
        $account=AmazonOauthToken::where('user_id',Auth::user()->id)->first();
        $access_token=$this->amazonAdsService->getAccessToken($account->refresh_token);
        $campaigns =$this->amazonAdsService->getCampaigns($access_token,$account->selling_partner_id);
        dd($campaigns);
    }
    public function getCampaignKeywords($campaignId){
        // dd($campaignId);
        $account=AmazonOauthToken::where('user_id',Auth::user()->id)->first();
        $access_token=$this->amazonAdsService->getAccessToken($account->refresh_token);
        $this->amazonAdsService->getCampaignKeywords($access_token,$account->selling_partner_id,$campaignId);
        return redirect()->back();
    }
    public function getCampaignAdsGroupList($campaignId){
        // dd($campaignId);
        $account=AmazonOauthToken::where('user_id',Auth::user()->id)->first();
        $access_token=$this->amazonAdsService->getAccessToken($account->refresh_token);
        $adgrouplist=$this->amazonAdsService->getCampaignAdsGroupList($access_token,$account->selling_partner_id,$campaignId);
         // Loop through the ad groups and save to the database
        foreach ($adgrouplist['adGroups'] as $adGroup) {
            // Assuming the default currency is USD, but you can modify it if needed
            $currency = 'USD';

            // Insert or update the ad group in the database
            AdGroup::updateOrCreate(
                ['ad_group_id' => $adGroup['adGroupId']], // Prevent duplicates
                [
                    'campaign_id' => $adGroup['campaignId'],
                    'ad_group_id' => $adGroup['adGroupId'],
                    'name' => $adGroup['name'],
                    'default_bid_value' => $adGroup['defaultBid'],
                    'default_bid_currency' => $currency,
                    'ad_group_status' => $adGroup['state'],
                ]
            );
        }
        return redirect()->back();
    }
    public function getCampaignPerformance($campaignId){
        // dd($campaignId);
        $account=AmazonOauthToken::where('user_id',Auth::user()->id)->first();
        $access_token=$this->amazonAdsService->getAccessToken($account->refresh_token);

        $adgrouplist=$this->amazonAdsService->generateAndDownloadReport($access_token,$account->selling_partner_id,$campaignId);
        // $adgrouplist=$this->amazonAdsService->getCampaignPerformanceData($access_token,$account->selling_partner_id,$campaignId);
    }
    public function getReport($reportId){
        
        $account=AmazonOauthToken::where('user_id',Auth::user()->id)->first();
        $access_token=$this->amazonAdsService->getAccessToken($account->refresh_token);
        $report=$this->amazonAdsService->checkReportStatus($access_token,$account->selling_partner_id,$reportId);
        
    }
    public function getReportData()
    {
        $startDate = date('Y-02-06'); // First day of the current month
        $endDate = date('Y-02-06'); // Last day of the current month
        $path = 'public/Reports/Report.json';
         if (Storage::exists($path)) {
            $json = Storage::get($path); // Get the file contents
            $data = json_decode($json, true); // Decode JSON to an array
            foreach($data as $record){
                // Save the record to the database
                CampaignPerformanceMetric::updateOrCreate([
                    'campaign_id'=>$record['campaignId'],
                    'start_date'=>$startDate,
                    'end_date'=>$endDate
                ],
                [
                    'impressions'=>$record['impressions']?? 0,
                    'clicks'=>$record['clicks']?? 0,
                    'cost'=>$record['cost']?? 0,
                    'sales1d'=>$record['sales1d']?? 0,
                    'sales7d'=>$record['sales7d']?? 0,
                    'sales14d'=>$record['sales14d']?? 0,
                    'sales30d'=>$record['sales30d']?? 0,
                    'attributed_sales_same_sku30d'=>$record['attributedSalesSameSku30d'] ?? 0,
                    'attributed_sales_same_sku14d'=>$record['attributedSalesSameSku14d'] ?? 0,
                    'attributed_sales_same_sku7d'=>$record['attributedSalesSameSku7d'] ?? 0,
                    'attributed_sales_same_sku1d'=>$record['attributedSalesSameSku1d']?? 0
                ]);
            }
            return response()->json([
                'success' => true,
                'data' => $data
            ]);
        } else {
            return response()->json([
                'success' => false,
                'message' => 'Report file not found'
            ], 404);
        }
    }
}
