<?php

namespace App\Http\Controllers;

use App\Models\Cart;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class CartController extends Controller
{
    public $user;

    public function __construct()
    {
        $this->user = Auth::user();
    }

    public function index()
    {
        if (isset($this->user)) {
            $cartItems = [];
            $totalAmount = 0;
            if ($this->user) {
                $cartItems = Cart::where('user_id', $this->user->id)->with('productsItem')->with('productsDetailsItem')->get();

                $totalAmount = $cartItems->sum(function ($item) {
                    return $item->productsDetailsItem->discount_price * $item->quantity;
                });
            }
        } else {
            return redirect()->route('login');
        }

        return view('pages.cart-page', ['cartItems' => $cartItems, 'totalAmount' => $totalAmount]);
    }

    public function store(Request $request)
    {
        $request->validate([
            'productId' => 'required',
        ]);
        // try {

        if (isset($this->user)) {

            $cartItem = Cart::where('user_id', $this->user->id)
                ->where('product_id', $request->productId)
                ->first();
            if (isset($cartItem)) {
                $cartItem->quantity = $cartItem->quantity + $request->qty;
            } else {
                $cartItem = new Cart;
                $cartItem->user_id = $this->user->id;
                $cartItem->product_id = $request->productId;
                $cartItem->product_details_id  = $request->product_details_id;
                $cartItem->quantity = $request->qty ?? 1;
            }
            $cartItem->save();
        } else {
            return redirect()->route('login');
        }
        //Mail::to('support@nutsons.com')->send(new SendContactInquiryMail($data));

        return redirect()->back()->with(
            'success',
            'Item added to cart'
        );
        // } catch (\Throwable $th) {
        //     return redirect()->back()->with('error', $th->getMessage());
        // }
    }

    public function destroy($id)
    {
        try {
            $cart = Cart::find($id);

            $cart->delete();
            return response()->json([
                'status' => true,
                'message' => 'Item deleted from cart.'
            ], 200);
            // return redirect()->back()->with('success', 'Item deleted from cart');
        } catch (\Throwable $th) {
            return response()->json([
                'status' => false,
                'message' => $th->getMessage()
            ], 500); // Adjust the status code based on the error
            // return redirect()->back()->with('error', $th->getMessage());
        }
    }

    public function update(Request $request, $id)
    {
        try {
            $cartItem = Cart::findOrFail($id);

            $cartItem->quantity = $request->quantity;
            $cartItem->save();

            return response()->json(['success' => true]);
        } catch (\Throwable $th) {
            return response()->json(['success' => false]);
        }
    }
}
