<?php

namespace App\Http\Controllers;

use Adyen\Client;
use Adyen\Environment;
use Adyen\Model\Checkout\PaymentMethodsRequest;
use Adyen\Service\Checkout\PaymentsApi;
use Adyen\Model\Checkout\Amount;
use Adyen\Service\Checkout;
use Adyen\Service\Payment;
use App\Models\Cart;
use App\Models\OrderDetail;
use App\Models\Orders;
use App\Models\Payment as LocalPayment;
use App\Models\UserBillingAddress;
use App\Models\UserShippingAddress;
use Exception;
use GuzzleHttp\Client as Gclient;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Adyen\Model\Checkout\CheckoutPaymentMethod;
use Adyen\Model\Checkout\PaymentRequest;
use Adyen\Model\Checkout\RiskData;
use App\Mail\OrderConfirmationMail;
use App\Mail\PaymentReceiptMail;
use Illuminate\Support\Facades\Mail;

class CheckoutController extends Controller
{
    public $user;

    public function __construct()
    {
        $this->user = Auth::user();
    }

    public function index(Request $request)
    {
        // dd(1);
        // $cartItems = [];
        // $totalAmount = 0.00;
        // $billingAddress = [];
        // $shippingAddress = [];
        // if ($this->user) {
        //     $cartItems = Cart::where('user_id', $this->user->id)->with('productsItem')->with('productsDetailsItem')->get();

        //     $billingAddress = UserBillingAddress::where('user_id', $this->user->id)->orderBy('id', 'DESC')->get()->first();

        //     $shippingAddress = UserShippingAddress::where('user_id', $this->user->id)->orderBy('id', 'DESC')->get()->first();

        //     $totalAmount = $cartItems->sum(function ($item) {
        //         return $item->productsDetailsItem->discount_price * $item->quantity;
        //     });
        // }
        // return view('pages.checkout-page', ['cartItems' => $cartItems, 'totalAmount' => $totalAmount, 'billingAddress' => $billingAddress, 'shippingAddress' => $shippingAddress]);
        $cartItems = Cart::where('user_id', $this->user->id)->with('productsItem', 'productsDetailsItem')->get();

        return view('front.pages.checkout', ['cartItems' => $cartItems, 'cart' => $cartItems]);
    }

    public function store(Request $request)
    {

        // Validate the incoming request
        $request->validate([
            'first_name' => 'required|string|max:255',
            'last_name' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'phone' => 'required|digits:10',
            'address' => 'required|string|max:255',
            'city' => 'required|string|max:100',
            'state' => 'required|string|max:100',
            'zip_code' => 'required|string|max:10',
            'country' => 'required|string',
            'total' => 'required|numeric|gt:0',
        ]);

        // Start a transaction
        // DB::beginTransaction();
        // try {

        // Store or update billing details
        UserBillingAddress::updateOrCreate(
            ['user_id' => $this->user->id],
            [
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'email' => $request->email,
                'contact' => $request->phone,
                'address' => $request->address,
                'country' => $request->country,
                'state' => $request->state,
                'city' => $request->city,
                'pincode' => $request->zip_code,
            ]
        );

        // // Store or update shipping details
        UserShippingAddress::updateOrCreate(
            ['user_id' => $this->user->id],
            [
                'address' => $request->address,
                'country' => $request->country,
                'state' => $request->state,
                'city' => $request->city,
                'pincode' => $request->zip_code,
            ]
        );

        //new adyen payment process starts here

        $client = new Client;
        $client->setXApiKey('AQEshmfxLY3JaRBDw0m/n3Q5qf3VbNJEGZtfWjIPn03S2qHukMqCvnm/M8rWiFAQwV1bDb7kfNy1WIxIIkxgBw==-lWUr4keA9OfDk6NQdkC1Vifm4wc4x8zI4lT1b0shjcI=-i1i4%d8#V~WYjFDBs*j');
        // For the live environment, additionally include your liveEndpointUrlPrefix.
        $client->setEnvironment(Environment::TEST);

        // Create the request object(s)
        $amount = new Amount;
        $amount
            ->setCurrency('USD')
            ->setValue($request->total * 100);

        $paymentMethodsRequest = new PaymentMethodsRequest;

        $paymentMethodsRequest
            ->setAmount($amount)
            ->setMerchantAccount('D9ithub799ECOM')
            ->setCountryCode('US')
            ->setChannel('Web');

        $requestOptions['idempotencyKey'] = 'UUID';


        // Send the request
        $service = new PaymentsApi($client);
        $response = $service->paymentMethods($paymentMethodsRequest, $requestOptions);
        return view('pages.adyencheckout')->with('paymentMethodsResponse', $response)->with('amount', $request->total);






























        //     // Set up the payment client
        //     $paymentClient = new Gclient;
        //     $payload = [
        //         'amount' => [
        //             'currency' => 'USD',
        //             'value' => $request->total * 100, // Payment value in minor units (e.g., $10.00)
        //         ],
        //         'reference' => $reference,
        //         'paymentMethod' => [
        //             'type' => 'scheme',
        //             'encryptedCardNumber' => 'test_4111111111111111',
        //             'encryptedExpiryMonth' => 'test_03',
        //             'encryptedExpiryYear' => 'test_2030',
        //             'encryptedSecurityCode' => 'test_737',
        //         ],
        //         'returnUrl' => route('payment.success'),
        //         'merchantAccount' => 'D9ithub799ECOM',
        //     ];

        //     // Send the request to Adyen API
        //     $response = $paymentClient->post('https://checkout-test.adyen.com/v71/payments', [
        //         'headers' => [
        //             'Content-Type' => 'application/json',
        //             'x-API-key' => 'AQEshmfxLY3JaRBDw0m/n3Q5qf3VbNJEGZtfWjIPn03S2qHukMqCvnm/M8rWiFAQwV1bDb7kfNy1WIxIIkxgBw==-lWUr4keA9OfDk6NQdkC1Vifm4wc4x8zI4lT1b0shjcI=-i1i4%d8#V~WYjFDBs*j', // Use env() for sensitive data
        //         ],
        //         'json' => $payload,
        //     ]);

        //     $decodedResponse = json_decode($response->getBody()->getContents(), true);
        //     if (! isset($decodedResponse['resultCode'])) {
        //         throw new Exception('Payment gateway response is invalid.');
        //     }
        //     if (isset($decodedResponse['resultCode']) && $decodedResponse['resultCode'] === 'Authorised') {
        //         $capturePayload = [
        //             'originalReference' => $decodedResponse['pspReference'],
        //             'merchantAccount' => 'D9ithub799ECOM',
        //             'modificationAmount' => [
        //                 'currency' => 'USD',
        //                 'value' => $request->total * 100, // Same amount as the payment
        //             ],
        //             'reference' => $reference,
        //         ];

        //         // Capture the payment
        //         $captureResponse = $paymentClient->post('https://pal-test.adyen.com/pal/servlet/Payment/v68/capture', [
        //             'headers' => [
        //                 'Content-Type' => 'application/json',
        //                 'x-API-key' => 'AQEshmfxLY3JaRBDw0m/n3Q5qf3VbNJEGZtfWjIPn03S2qHukMqCvnm/M8rWiFAQwV1bDb7kfNy1WIxIIkxgBw==-lWUr4keA9OfDk6NQdkC1Vifm4wc4x8zI4lT1b0shjcI=-i1i4%d8#V~WYjFDBs*j',
        //             ],
        //             'json' => $capturePayload,
        //         ]);

        //         $captureDecodedResponse = json_decode($captureResponse->getBody()->getContents(), true);
        //         if (! isset($captureDecodedResponse['response']) || $captureDecodedResponse['response'] !== '[capture-received]') {
        //             throw new Exception('Payment capture failed.');
        //         }
        //         // Create order after successful payment capture
        //         $payments = LocalPayment::create([
        //             'payment_id' => $decodedResponse['pspReference'],
        //             'payer_id' => $this->user->id,
        //             'payer_name' => $this->user->name,
        //             'payer_email' => $this->user->email,
        //             'payment_status' => $captureDecodedResponse['response'],
        //             'amount' => $request->total,
        //             'currency' => 'USD',
        //             'payment_method' => 'CARD',
        //         ]);

        //         $order = Orders::create([
        //             'user_id' => $this->user->id,
        //             'payment_id' => $payments->id,
        //             'shipping_id' => $shippingDetails->id,
        //             'billing_id' => $billingDetails->id,
        //             'sub_total' => $request->total,
        //             'grand_total' => $request->total,
        //             'payment_reference' => $reference,
        //             'order_status' => 'confirmed',
        //         ]);

        //         // Process order details
        //         $carts = Cart::whereIn('id', $request->cartid)->get();
        //         foreach ($carts as $cart) {
        //             OrderDetail::create([
        //                 'order_id' => $order->id,
        //                 'product_id' => $cart->product_id,
        //                 'product_details_id' => $cart->product_details_id,
        //                 'quantity' => $cart->quantity,
        //                 'product_price' => 0,
        //             ]);
        //         }
        //         // Delete the cart items that match the provided IDs
        //         Cart::whereIn('id', $request->cartid)->delete();
        //         // Commit the transaction
        //         DB::commit();

        //         return redirect()->back()->with('success', 'Payment captured successfully!');

        //     } else {
        //         // If payment is not authorized
        //         throw new Exception('Payment not authorized. Please try again.');
        //     }
        // } catch (Exception $e) {
        //     // Rollback the transaction if something goes wrong
        //     DB::rollBack();

        //     // Log the error message
        //     Log::error('Payment processing error: '.$e->getMessage());

        //     return redirect()->back()->with('error', $e->getMessage());
        // }
    }
    public function payments(Request $request)
    {
        $reference = 'order-' . uniqid();
        // try {

        $client = new Client();
        $client->setXApiKey("AQEshmfxLY3JaRBDw0m/n3Q5qf3VbNJEGZtfWjIPn03S2qHukMqCvnm/M8rWiFAQwV1bDb7kfNy1WIxIIkxgBw==-lWUr4keA9OfDk6NQdkC1Vifm4wc4x8zI4lT1b0shjcI=-i1i4%d8#V~WYjFDBs*j");
        // For the live environment, additionally include your liveEndpointUrlPrefix.
        $client->setEnvironment(Environment::TEST);
        $riskData = new RiskData();
        $riskData->setClientData($request->paymentData['riskData']['clientData']);


        $checkoutPaymentMethod = new CheckoutPaymentMethod();
        $checkoutPaymentMethod
            ->setEncryptedCardNumber($request->paymentData['paymentMethod']['encryptedCardNumber'])
            ->setEncryptedSecurityCode($request->paymentData['paymentMethod']['encryptedSecurityCode'])
            ->setEncryptedExpiryYear($request->paymentData['paymentMethod']['encryptedExpiryYear'])
            ->setEncryptedExpiryMonth($request->paymentData['paymentMethod']['encryptedExpiryMonth'])
            ->setType($request->paymentData['paymentMethod']['type']);


        $paymentRequest = new PaymentRequest();
        $paymentRequest
            ->setReference($reference)
            ->setAmount($request->amount)
            ->setMerchantAccount("D9ithub799ECOM")
            ->setPaymentMethod($checkoutPaymentMethod)
            ->setReturnUrl(route('payment.success'))
            ->setRiskData($riskData);


        // Send the request
        $service = new PaymentsApi($client);
        $response = $service->payments($paymentRequest);
        $result = json_encode($response);
        $result = json_decode($result, true);
        if (isset($result['resultCode']) && $result['resultCode'] === 'Authorised') {
            $capturePayload = [
                'originalReference' => $result['pspReference'],
                'merchantAccount' => 'D9ithub799ECOM',
                'modificationAmount' => $request->amount,
                'reference' => $reference,
            ];
            $paymentClient = new Gclient;
            // Capture the payment
            $captureResponse = $paymentClient->post('https://pal-test.adyen.com/pal/servlet/Payment/v68/capture', [
                'headers' => [
                    'Content-Type' => 'application/json',
                    'x-API-key' => 'AQEshmfxLY3JaRBDw0m/n3Q5qf3VbNJEGZtfWjIPn03S2qHukMqCvnm/M8rWiFAQwV1bDb7kfNy1WIxIIkxgBw==-lWUr4keA9OfDk6NQdkC1Vifm4wc4x8zI4lT1b0shjcI=-i1i4%d8#V~WYjFDBs*j',
                ],
                'json' => $capturePayload,
            ]);
            $captureDecodedResponse = json_decode($captureResponse->getBody()->getContents(), true);
            if (! isset($captureDecodedResponse['response']) || $captureDecodedResponse['response'] !== '[capture-received]') {
                throw new Exception('Payment capture failed.');
            }
            // Create order after successful payment capture
            $payments = LocalPayment::create([
                'payment_id' => $result['pspReference'],
                'payer_id' => $this->user->id,
                'payer_name' => $this->user->name,
                'payer_email' => $this->user->email,
                'payment_status' => $captureDecodedResponse['response'],
                'amount' => $request->amount['value'],
                'currency' => 'USD',
                'payment_method' => 'CARD',
            ]);
            $shippingDetails = UserShippingAddress::where('user_id', $this->user->id)->first();
            $billingDetails = UserBillingAddress::where('user_id', $this->user->id)->first();
            $order = Orders::create([
                'user_id' => $this->user->id,
                'payment_id' => $payments->id,
                'shipping_id' => $shippingDetails->id,
                'billing_id' => $billingDetails->id,
                'sub_total' => $request->amount['value'],
                'grand_total' => $request->amount['value'],
                'payment_reference' => $reference,
                'order_status' => 'confirmed',
            ]);
            $carts = Cart::where('user_id', $this->user->id)->get();
            foreach ($carts as $cart) {
                OrderDetail::create([
                    'order_id' => $order->id,
                    'product_id' => $cart->product_id,
                    'product_details_id' => $cart->product_details_id,
                    'quantity' => $cart->quantity,
                    'product_price' => 0,
                ]);
            }
            // Delete the cart items that match the provided IDs
            Cart::where('user_id', $this->user->id)->delete();
            $paymentdetails = LocalPayment::with('order', 'orderDetails', 'orderDetails.product', 'orderDetails.productDetails', 'billingAddress')->findOrFail($payments->id);
            Mail::to(Auth::user()->email)->send(new PaymentReceiptMail($paymentdetails));

            $order_details = Orders::with('orderDetails', 'payment', 'billingAddress', 'orderDetails.product', 'orderDetails.productDetails')->findOrFail($order->id);
            Mail::to(Auth::user()->email)->send(new OrderConfirmationMail($order_details));
            return response()->json(["resultCode" => 'Authorised', "action" => null, "order" =>  $order, "donationToken" => null]);
        }
        return response()->json(["resultCode" => 'refused', "action" => null, "order" => null, "donationToken" => null]);
        // } catch (Exception $e) {
        //     // Log the error message for debugging
        //     Log::error('Payment processing error: ' . $e->getMessage());
        //     return response()->json(["resultCode" => 500, "action" => 'failed', "order" => null, "donationToken" => null]);
        // }
    }
    public function payment_details(Request $request)
    {
        $order_details = Orders::with('orderDetails', 'payment', 'billingAddress', 'orderDetails.product', 'orderDetails.productDetails')->findOrFail(2);
        $paymentdetails = LocalPayment::with('order', 'orderDetails', 'orderDetails.product', 'orderDetails.productDetails', 'billingAddress')->findOrFail(2);
        Mail::to(Auth::user()->email)->send(new OrderConfirmationMail($order_details));
        Mail::to(Auth::user()->email)->send(new PaymentReceiptMail($paymentdetails));

        // $payment = LocalPayment::with('order', 'orderDetails', 'orderDetails.product', 'orderDetails.productDetails', 'billingAddress')->findOrFail(2);

        // return view('mail.payment_confirmation', compact('payment'));
        // $order_details = Orders::with('orderDetails', 'payment', 'billingAddress', 'orderDetails.product', 'orderDetails.productDetails')->findOrFail(2);
        // return view('mail.order_confirmation', ['order' => $order_details]);
        // Mail::to(Auth::user()->email)->send(new OrderConfirmationMail($order_details));
    }

    public function paymentSuccess(Request $request)
    {
        Log::info($request);
        dd(1);
    }
    public function generateUUIDv4()
    {
        return sprintf(
            '%04x%04x-%04x-%04x-%04x-%04x%04x%04x',
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff),
            mt_rand(0, 0x0fff) | 0x4000,
            mt_rand(0, 0x3fff) | 0x8000,
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff),
            mt_rand(0, 0xffff)
        );
    }
}
