<?php

namespace App\Http\Controllers;

use App\Models\AdGroup;
use App\Models\AdReportTask;
use App\Models\AmazonOauthToken;
use App\Models\CampaignKeyword;
use App\Services\EbayApiClient;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Http;


class EbayController extends Controller
{
    //
    public function syncReportTask(){
        $apiClient = new EbayApiClient;
        $campaign = $apiClient->getReportTasks();
        // // dd($campaign);
        $tasks = $campaign['reportTasks'] ?? [];
        // dd($tasks);

        foreach ($tasks as $task) {
            AdReportTask::updateOrCreate(
                ['task_id' => $task['reportTaskId']],
                [
                    'report_name' => $task['reportName'] ?? null,
                    'dimensions' => $task['dimensions'] ?? null,
                    'metrics' => $task['metrics'] ?? null,
                    'campaign_ids' => $task['campaignIds'] ?? null,
                    'date_from' => $task['dateFrom'] ?? null,
                    'date_to' => $task['dateTo'] ?? null,
                    'expected_completion_date' => $task['reportTaskExpectedCompletionDate'] ?? null,
                    'creation_date' => $task['reportTaskCreationDate'] ?? null,
                    'completion_date' => $task['reportTaskCompletionDate'] ?? null,
                    'expiration_date' => $task['reportTaskExpirationDate'] ?? null,
                    'status' => $task['reportTaskStatus'],
                    'report_id' => $task['reportId'] ?? null,
                    'report_url' => $task['reportHref'] ?? null,
                ]
            );
        }
        return redirect()->route('Ebay.index');
    }

    public function getCampaignKeywords($campaignId){
        $apiClient = new EbayApiClient;
        $keywords = $apiClient->getCampaignKeywords($campaignId);
        if (isset($keywords) && is_array($keywords)) {
            foreach ($keywords as $keywordData) {
                // Insert or update the keyword record
                CampaignKeyword::updateOrCreate(
                    [
                        'campaign_id' => $campaignId,
                        'keyword_id' => $keywordData['keywordId'],
                    ],
                    [
                        'keyword_text' => $keywordData['keywordText'],
                        'ad_group_id' => $keywordData['adGroupId'],
                        'match_type' => $keywordData['matchType'],
                        'keyword_status' => $keywordData['keywordStatus'],
                        'normalized_keyword_text' => $keywordData['normalizedKeywordText'],
                        'bid_value' => $keywordData['bid']['value'],
                        'bid_currency' => $keywordData['bid']['currency'],
                    ]
                );
            }
        }
        return redirect()->back();
        // return redirect()->route('Ebay.Campaigns.details', ['campid' => $campaignId]);
    }

    public function getCampaignAds($campaignId){
        $apiClient = new EbayApiClient;
        $ads = $apiClient->getCampaignAds($campaignId);
        foreach($ads['ads'] as $ad){
            $details=$apiClient->getAdsDetail($campaignId,$ad['adId']);
            dd($details);
        }
        dd($ads);
    }

    public function getCampaignAdGroups($campaignId){
        $apiClient = new EbayApiClient;
        $adGroups = $apiClient->getCampaignAdGroups($campaignId);
        foreach ($adGroups as $group) {
            // Save the group to the database
            AdGroup::updateOrInsert(
                [
                    'ad_group_id' => $group['adGroupId'], // Unique constraint
                ],
                [
                    'campaign_id' => $campaignId,
                    'name' => $group['name'] ?? '',
                    'default_bid_value' => $group['defaultBid']['value'] ?? 0.00,
                    'default_bid_currency' => $group['defaultBid']['currency'] ?? '',
                    'ad_group_status' => $group['adGroupStatus'] ?? 'UNKNOWN',
                    'created_at' => now(),
                    'updated_at' => now(),
                ]
            );
        }
        return redirect()->back();
    }
    public function test(){
        $apiClient = new EbayApiClient;
        $campaigns = $apiClient->getOAuthToken('v%5E1.1%23i%5E1%23p%5E3%23f%5E0%23I%5E3%23r%5E1%23t%5EUl41XzM6Qzk1MzYzNDAyQUYxODAyOERCOTY5NjE4OUUyQUQ2RjhfMl8xI0VeMjYw');
        dd($campaigns);
    }
    
    public function handleEbayCallback(Request $request){
         // Step 1: Get the authorization code from the URL
        $code = $request->query('code');

        if (!$code) {
            return response()->json(['error' => 'Authorization code not found'], 400);
        }

        // Step 2: Prepare API request data
        $clientId = env('EBAY_APP_ID'); // eBay Client ID
        $clientSecret = env('EBAY_CERT_ID'); // eBay Cert ID (Client Secret)
        $redirectUri = env('EBAY_REDIRECT_URI');

        // Decode the code in case of URL encoding issues
        $decodedCode = urldecode($code);

        $tokenUrl = "https://api.ebay.com/identity/v1/oauth2/token";

        // Step 3: Make the request to get the access token
        $response = Http::withOptions([
            'verify' => false, // Disable SSL verification
        ])->withHeaders([
            'Authorization' => 'Basic ' . base64_encode("$clientId:$clientSecret"), // Base64 encode credentials
            'Content-Type' => 'application/x-www-form-urlencoded'
        ])->asForm()->post($tokenUrl, [
            'grant_type' => 'authorization_code',
            'code' => $decodedCode,
            'redirect_uri' => $redirectUri
        ]);

        // Step 4: Get the response
        $data = $response->json();
        if ($response->failed() || empty($data['access_token']) || empty($data['refresh_token'])) {
            return response()->json([
                'error' => 'Failed to retrieve access token',
                'details' => $data
            ], 400);
        }
        AmazonOauthToken::updateOrCreate(
            ['user_id' => Auth::user()->id, 'marketplace_id' => 'ebay'],
            [
                'access_token' => $data['access_token'],
                'refresh_token' => $data['refresh_token'],
                'access_token_expiry' => now()->addSeconds($data['expires_in']),
            ]
        );
        return redirect()->route('channels.creat')->with('success', 'eBay account linked successfully!');
    }
   
}
