<?php

namespace App\Http\Controllers;

use App\Models\Orders;
use App\Models\UserShippingAddress;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class OrderController extends Controller
{
    protected $user;

    public function __construct()
    {
        $this->user = Auth::user();
    }

    //
    public function index()
    {
        // Fetch all orders with their billing address
        $orders = Orders::with('billingAddress')->paginate(10);

        // Return the view and pass the orders data
        return view('admin.orders.index', compact('orders'));
    }

    public function Show($order_id)
    {
        try {
            // Fetch the order by ID
            $order = Orders::with('orderDetails', 'payment', 'billingAddress', 'orderDetails.product', 'orderDetails.productDetails')->findOrFail($order_id);
            $shipping_address = UserShippingAddress::where('user_id', $this->user->id)->get()->first();

            // Return the view with order data
            return view('admin.orders.view', compact('order', 'shipping_address'));
        } catch (ModelNotFoundException $e) {
            return redirect()->route('orders.index')->with('error', 'Order not found.');
        }
    }

    public function userOrderList(Request $request)
    {
        // dd($request);
        $order = Orders::where('user_id', $this->user->id)->with('orderDetails', 'payment', 'orderDetails.product', 'orderDetails.productDetails')->paginate(5);

        return view('front.pages.order', ['orders' => $order]);
    }
}
