<?php

namespace App\Jobs;

use App\Models\AmazonOauthToken;
use App\Models\ReportRequest;
use App\Services\AmazonAdsService;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Queue\Queueable;
use Illuminate\Queue\SerializesModels;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Support\Facades\Log;

class CheckReportStatus implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue,Queueable,SerializesModels;
    protected $request_id;
    /**
     * Create a new job instance.
     */
    public function __construct($request_id)
    {
        //
        $this->request_id=$request_id;
    }

    /**
     * Execute the job.
     */
    public function handle(): void
    {
        //
        $reportRequest = ReportRequest::find($this->request_id);
        $account=AmazonOauthToken::find($reportRequest->auth_token_id);
        
       
        $amazonAdsService = new AmazonAdsService();
        $access_token=$amazonAdsService->getAccessToken($account->refresh_token);
        $responseData=$amazonAdsService->checkReportStatus($access_token,$account->selling_partner_id,$reportRequest->report_id);

        if($responseData['success'] != true){
            CheckReportStatus::dispatch($this->request_id)->delay(now()->addMinutes(15));
        }

        Log::info('job executed successfuly and report processed successfully');
    }
}
