<?php

namespace App\Livewire\Admin\AdsCampaign;

use App\Models\CampaignPerformanceMetric;
use Livewire\Component;
use Livewire\WithPagination;
use Illuminate\Support\Facades\DB;


class CampaignReport extends Component
{
    use WithPagination;
    public $promotionreport;
    public $startDate; // Start date filter
    public $endDate;   // End date filter
    public $grouping = 'daily'; // Default grouping
    public $daterange;

    public function filterData()
    {
        $query = CampaignPerformanceMetric::query();

        if ($this->startDate) {
            $query->where('start_date', '>=', $this->startDate);
        }

        if ($this->endDate) {
            $query->where('end_date', '<=', $this->endDate);
        }

        switch ($this->grouping) {
            case 'daily':
                $query->select(
                            'start_date as formatted_date',
                            'campaign_id',
                            DB::raw('SUM(impressions) as total_impressions'),
                            DB::raw('SUM(clicks) as total_clicks'),
                            DB::raw('SUM(cost) as total_cost'),
                            DB::raw('SUM(sales1d) as total_sales1d'),
                            DB::raw('SUM(sales7d) as total_sales7d'),
                            DB::raw('SUM(sales14d) as total_sales14d'),
                            DB::raw('SUM(sales30d) as total_sales30d'),
                            DB::raw('SUM(attributed_sales_same_sku30d) as total_attributed_sales_30d'),
                            DB::raw('SUM(attributed_sales_same_sku14d) as total_attributed_sales_14d'),
                            DB::raw('SUM(attributed_sales_same_sku7d) as total_attributed_sales_7d'),
                            DB::raw('SUM(attributed_sales_same_sku1d) as total_attributed_sales_1d'),
                            DB::raw('ROUND(SUM(sales1d) / NULLIF(SUM(cost), 0), 2) as croas'),
                            DB::raw('ROUND((SUM(cost) / NULLIF(SUM(sales1d), 0)) * 100, 2) as cacos'),
                            DB::raw('ROUND(SUM(cost) / NULLIF(SUM(clicks), 0), 2) as ccpc'),
                            DB::raw('ROUND((SUM(clicks) / NULLIF(SUM(impressions), 0)) * 100, 2) as cctr'),
                            DB::raw('ROUND(SUM(cost) / NULLIF(SUM(impressions), 0), 6) as ccpi'),
                            DB::raw('ROUND((SUM(sales30d) / NULLIF(SUM(clicks), 0)) * 100, 2) as ccvr')
                        )->groupBy('start_date', 'campaign_id')
                        ->orderBy('start_date', 'asc');
                break;

            case 'weekly':
                    $query->selectRaw('
                        MIN(start_date) as week_start_date, 
                        MAX(start_date) as week_end_date, 
                        campaign_id,
                        SUM(impressions) as total_impressions,
                        SUM(clicks) as total_clicks,
                        SUM(cost) as total_cost,
                        SUM(sales1d) as total_sales1d,
                        SUM(sales7d) as total_sales7d,
                        SUM(sales14d) as total_sales14d,
                        SUM(sales30d) as total_sales30d,
                        SUM(attributed_sales_same_sku30d) as total_attributed_sales_30d,
                        SUM(attributed_sales_same_sku14d) as total_attributed_sales_14d,
                        SUM(attributed_sales_same_sku7d) as total_attributed_sales_7d,
                        SUM(attributed_sales_same_sku1d) as total_attributed_sales_1d,
                        ROUND(SUM(sales1d) / NULLIF(SUM(cost), 0), 2) as croas,
                        ROUND((SUM(cost) / NULLIF(SUM(sales1d), 0)) * 100, 2) as cacos,
                        ROUND(SUM(cost) / NULLIF(SUM(clicks), 0), 2) as ccpc,
                        ROUND((SUM(clicks) / NULLIF(SUM(impressions), 0)) * 100, 2) as cctr,
                        ROUND(SUM(cost) / NULLIF(SUM(impressions), 0), 6) as ccpi,
                        ROUND((SUM(sales30d) / NULLIF(SUM(clicks), 0)) * 100, 2) as ccvr')
                    ->whereBetween('start_date', [$this->startDate, $this->endDate])
                    ->groupBy(DB::raw('YEAR(start_date), WEEK(start_date), campaign_id'))
                    ->orderBy(DB::raw('YEAR(start_date)'))
                    ->orderBy(DB::raw('WEEK(start_date)'));

                break;

            case 'monthly':
                $query->selectRaw('
                    DATE_FORMAT(MIN(start_date), "%Y-%m-01") as month_start_date,
                    LAST_DAY(MIN(start_date)) as month_end_date,
                    campaign_id,
                    SUM(impressions) as total_impressions,
                    SUM(clicks) as total_clicks,
                    SUM(cost) as total_cost,
                    SUM(sales1d) as total_sales1d,
                    SUM(sales7d) as total_sales7d,
                    SUM(sales14d) as total_sales14d,
                    SUM(sales30d) as total_sales30d,
                    SUM(attributed_sales_same_sku30d) as total_attributed_sales_30d,
                    SUM(attributed_sales_same_sku14d) as total_attributed_sales_14d,
                    SUM(attributed_sales_same_sku7d) as total_attributed_sales_7d,
                    SUM(attributed_sales_same_sku1d) as total_attributed_sales_1d,
                    ROUND(SUM(sales1d) / NULLIF(SUM(cost), 0), 2) as croas,
                    ROUND((SUM(cost) / NULLIF(SUM(sales1d), 0)) * 100, 2) as cacos,
                    ROUND(SUM(cost) / NULLIF(SUM(clicks), 0), 2) as ccpc,
                    ROUND((SUM(clicks) / NULLIF(SUM(impressions), 0)) * 100, 2) as cctr,
                    ROUND(SUM(cost) / NULLIF(SUM(impressions), 0), 6) as ccpi,
                    ROUND((SUM(sales30d) / NULLIF(SUM(clicks), 0)) * 100, 2) as ccvr')
                ->whereBetween('start_date', [$this->startDate, $this->endDate])
                ->groupBy(DB::raw('YEAR(start_date), MONTH(start_date), campaign_id'))
                ->orderBy(DB::raw('YEAR(start_date)'))
                ->orderBy(DB::raw('MONTH(start_date)'));

               break;
        }

        return $query->whereHas('ebayCampaign')->with('ebayCampaign')->paginate(5); // Paginate the results

    }
    public function resetTable()
    {
        $this->startDate=false;
        $this->endDate=false;    
        $this->grouping = 'daily';
    }

    public function render()
    {
        $analytics = $this->filterData();

        return view('livewire.admin.ads-campaign.campaign-report',compact('analytics'))->layout('components.layouts.admin');
    }
}
