<?php

namespace App\Livewire\Admin\Channels;

use App\Models\AmazonOauthToken;
use Illuminate\Support\Facades\Auth;
use Livewire\Component;

class Add extends Component
{

    public $accounts=null;
    public $installedMarket = null;
    public $selectedMarketplace = null;
    public $marketplaces = [
        ['id' => 'amazon', 'name' => 'Amazon', 'logo' => 'https://upload.wikimedia.org/wikipedia/commons/a/a9/Amazon_logo.svg'],
        ['id' => 'ebay', 'name' => 'eBay', 'logo' => 'https://upload.wikimedia.org/wikipedia/commons/1/1b/EBay_logo.svg'],
    ];

    public $regions = [];

    protected $amazonRegions = [
        ['id' => 'na', 'name' => 'North America', 'flag_code' => 'us', 'endpoint' => 'https://advertising-api.amazon.com'],
        ['id' => 'eu', 'name' => 'Europe', 'flag_code' => 'eu', 'endpoint' => 'https://advertising-api-eu.amazon.com'],
        ['id' => 'fe', 'name' => 'Far East', 'flag_code' => 'jp', 'endpoint' => 'https://advertising-api-fe.amazon.com'],
    ];

    protected $ebayRegions = [
        ['id' => 'us', 'name' => 'United States', 'flag_code' => 'us', 'auth_url' => 'https://auth.ebay.com/oauth2/authorize'],
        ['id' => 'uk', 'name' => 'United Kingdom', 'flag_code' => 'gb', 'auth_url' => 'https://auth.ebay.co.uk/oauth2/authorize'],
        ['id' => 'de', 'name' => 'Germany', 'flag_code' => 'de', 'auth_url' => 'https://auth.ebay.de/oauth2/authorize'],
        ['id' => 'au', 'name' => 'Australia', 'flag_code' => 'au', 'auth_url' => 'https://auth.ebay.com.au/oauth2/authorize'],
    ];

    public function mount()
    {
        $this->regions = $this->amazonRegions;
    }

    public function install($marketplaceId)
    {
        $this->installedMarket = $marketplaceId;
        if ($marketplaceId === 'amazon') {
            $this->regions = $this->amazonRegions;
        } 
        elseif ($marketplaceId === 'ebay') {
            $this->regions = $this->ebayRegions;
        } 
        else {
            $this->regions = [];
        }
    }

    public function selectMarketplace($regionId)
    {
        $this->selectedMarketplace = $regionId;

        if ($this->installedMarket === 'amazon') {
            $clientId = env('AMAZON_CLIENT_ID');
            $redirectUri = "https://amazon.com"; // Keeping this as per your request

            // Define API authentication URLs for different regions
            $amazonAuthUrls = [
                'us' => 'https://www.amazon.com/ap/oa',
                'uk' => 'https://www.amazon.co.uk/ap/oa',
                'in' => 'https://www.amazon.in/ap/oa',
            ];

            // Get the correct authentication URL based on the selected region
            $authBaseUrl = $amazonAuthUrls[$regionId] ?? $amazonAuthUrls['us']; // Default to 'us' if not found

            // Construct authentication URL
            $authUrl = "{$authBaseUrl}?client_id={$clientId}&scope=advertising::campaign_management&response_type=code&redirect_uri={$redirectUri}";

            return redirect()->away($authUrl);
        }
        elseif ($this->installedMarket === 'ebay') {
            $clientId = env('EBAY_APP_ID');
            $redirectUri = urlencode(env('EBAY_REDIRECT_URI'));

            $ebayAuthUrls = [
                'us' => 'https://auth.ebay.com/oauth2/authorize',
                'uk' => 'https://auth.ebay.co.uk/oauth2/authorize',
                'de' => 'https://auth.ebay.de/oauth2/authorize',
                'au' => 'https://auth.ebay.com.au/oauth2/authorize',
            ];

            $authBaseUrl = $ebayAuthUrls[$regionId] ?? $ebayAuthUrls['uk'];
            $authUrl = "{$authBaseUrl}?client_id={$clientId}&redirect_uri={$redirectUri}&response_type=code&scope=https://api.ebay.com/oauth/api_scope";
            AmazonOauthToken::updateOrCreate(
                ['user_id' => Auth::user()->id, 'marketplace_id' => 'ebay'],
                [
                    'access_token' => "SampleAccessToken",
                    'refresh_token' => "SampleRefreshToken",
                    'access_token_expiry' => now(),
                    'region'=>$regionId,
                ]
            );
            return redirect()->away($authUrl);
        }
    }

    public function render()
    {
        $this->accounts=AmazonOauthToken::where('user_id',Auth::user()->id)->get();
        return view('livewire.admin.channels.add')->layout('components.layouts.admin');
    }
}
