<?php

namespace App\Livewire\Admin;

use App\Models\Contact; // Import the Contact model
use App\Models\EbayAnalytics;
use App\Models\NewsletterSubscriber;
use App\Models\Orders;
use App\Models\Payment;
use App\Models\Product;
use App\Models\ProductCategory;
use App\Models\SubCategory;
use App\Models\User;
use App\Services\EbayApiClient;
use Illuminate\Pagination\Paginator;
use Livewire\Component;
use Livewire\WithPagination;
use Illuminate\Support\Facades\DB;



class Dashboard extends Component
{
    use WithPagination;
    public $summarypromotionReport;
    public $promotionreport;
    public $startDate; // Start date filter
    public $endDate;   // End date filter
    public $grouping = 'daily'; // Default grouping
    public function mount()
    {
        $report=new EbayApiClient();
        $this->summarypromotionReport = $report->getPromotionSummaryReport();
        
    }
    
    public function filterData()
    {
         $query = EbayAnalytics::query();

        if ($this->startDate) {
            $query->where('report_date', '>=', $this->startDate);
        }

        if ($this->endDate) {
            $query->where('report_date', '<=', $this->endDate);
        }

        switch ($this->grouping) {
            case 'daily':
                $query->select(
                    'report_date as formatted_date',
                    'marketplace_id',
                    DB::raw('SUM(listing_impression_search_results_page) as listing_impression_search_results_page'),
                    DB::raw('SUM(listing_impression_home_page) as listing_impression_home_page'),
                    DB::raw('SUM(transaction) as transaction'),
                    DB::raw('SUM(unique_transactions) as unique_transactions'),
                    DB::raw('SUM(buyer_views) as buyer_views'),
                    DB::raw('SUM(total_sales) as total_sales'),
                    DB::raw('SUM(buyers) as buyers'),
                    DB::raw('SUM(buy_box_purchases) as buy_box_purchases'),
                    DB::raw('SUM(listing_views) as listing_views')
                )->groupBy('report_date', 'marketplace_id')
                 ->orderBy('report_date', 'asc'); // Ensure ordering by report_date
                break;

            case 'weekly':
                $query->selectRaw('
                        MIN(report_date) as week_start_date, 
                        MAX(report_date) as week_end_date, 
                        marketplace_id,
                        SUM(listing_impression_search_results_page) as listing_impression_search_results_page,
                        SUM(listing_impression_home_page) as listing_impression_home_page,
                        SUM(transaction) as transaction,
                        SUM(unique_transactions) as unique_transactions,
                        SUM(buyer_views) as buyer_views,
                        SUM(total_sales) as total_sales,
                        SUM(buyers) as buyers,
                        SUM(buy_box_purchases) as buy_box_purchases,
                        SUM(listing_views) as listing_views
                    ')
                    ->whereBetween('report_date', [$this->startDate, $this->endDate])
                    ->groupBy(DB::raw('YEAR(report_date), WEEK(report_date), marketplace_id'))
                    ->orderBy(DB::raw('YEAR(report_date)'))
                    ->orderBy(DB::raw('WEEK(report_date)'));
                break;

            case 'monthly':
                $query->selectRaw('
                    DATE_FORMAT(MIN(report_date), "%Y-%m-01") as month_start_date,
                    LAST_DAY(MIN(report_date)) as month_end_date,
                    marketplace_id,
                    SUM(listing_impression_search_results_page) as listing_impression_search_results_page,
                    SUM(listing_impression_home_page) as listing_impression_home_page,
                    SUM(transaction) as transaction,
                    SUM(unique_transactions) as unique_transactions,
                    SUM(buyer_views) as buyer_views,
                    SUM(total_sales) as total_sales,
                    SUM(buyers) as buyers,
                    SUM(buy_box_purchases) as buy_box_purchases,
                    SUM(listing_views) as listing_views
                ')
                ->whereBetween('report_date', [$this->startDate, $this->endDate])
                ->groupBy(DB::raw('YEAR(report_date), MONTH(report_date), marketplace_id'))
                ->orderBy(DB::raw('YEAR(report_date)'))
                ->orderBy(DB::raw('MONTH(report_date)'));
                break;
        }

        return $query->paginate(5); // Paginate the results

    }
    public function resetTable()
    {
        $this->startDate=false;
        $this->endDate=false;    
        $this->grouping = 'daily';
    }

    public function render()
    {
        // $analytics = $this->filterData();
        
        return view('livewire.admin.dashboard')->layout('components.layouts.admin');
    }
}
