<?php

namespace App\Livewire\Admin\Product;

use App\Models\ProductCategory;
use App\Models\ProductDetail;
use App\Models\Storage;
use App\Models\SubCategory;
use App\Services\FileService;
use App\Services\ProductServices;
use Livewire\Component;
use Livewire\WithFileUploads;
use WireUi\Traits\WireUiActions;
use Illuminate\Http\Request;


class Create extends Component
{
    use WireUiActions, WithFileUploads;

    public $name;
    public $description;
    public $advantage;
    public $sub_category_id;
    public array $packaging_details = [
        [
            'tittle' => null,
            'value' => null,

        ],
    ];
    public $main_photo = null;
    public $main_category;
    public array $photos = [];

    public $newPhoto;

    public function store(ProductServices $productServices, FileService $fileService, Request $request)
    {
        // dd($this->main_category,$this->sub_category_id);
        // Use dd() to output them
        $this->validate([
            'name' => 'required|string|max:255',
            'description' => 'required',
            'main_photo' => 'nullable|image',
            'photos.*' => 'nullable|image',
        ]);
        $data = [
            'name' => $this->name,
            'description' => $this->description,
            'category_id' => $this->sub_category_id,
            'main_category'=>$this->main_category,
            'status' => 1,
        ];

        $product = $productServices->create($data);

        ProductDetail::create([
            'advantages' => $this->advantage,
            'characteristics' => json_encode(array_column($this->packaging_details, 'value', 'tittle')),
            'product_id' => $product->id,
        ]);
        $upload = $fileService->uploadFile(
            $this->main_photo,
            'products',
        );
        Storage::create([
            'file_path' => $upload['path'],
            'table_id' => $product->id,
            'table_type' => 'product_main_image',
        ]);
        if ($this->photos) {
            foreach ($this->photos as $value) {
                $uploaded = $fileService->uploadFile(
                    $value,
                    'products',
                );
                Storage::create([
                    'file_path' => $uploaded['path'],
                    'table_id' => $product->id,
                    'table_type' => 'product_other_image',
                ]);
            }
        }

        $this->notification()->success('Success notification');

        return redirect()->to(route('products.index'));
    }

    public function addMorePackagingDetail(): void
    {
        $this->packaging_details[] = [
            'tittle' => null,
            'value' => null,
        ];
    }

    public function removePackagingDetail($index): void
    {
        unset($this->packaging_details[$index]);
        $this->packaging_details = array_values($this->packaging_details); // Re-index the array
    }

    public function updatedNewPhoto(): void
    {
        $this->photos[] = $this->newPhoto;
    }

    public function removePhoto($index): void
    {
        array_splice($this->photos, $index, 1);
    }

    public static function cleanUrlV2($str)
    {
        $clean = preg_replace("/[^a-zA-Z0-9\/_|+ -]/", '-', $str);
        $clean = strtolower(trim($clean, '-'));
        $clean = preg_replace("/[\/_|+ -]+/", '-', $clean);

        return $clean;
    }

    public function render()
    {
        $categories = SubCategory::where('status', true)->whereHas('category')->with('category')->get();
        $maincategory=ProductCategory::where('status',true)->get();
        return view('livewire.admin.product.create', ['categories' => $categories,'maincategory'=>$maincategory])->layout('components.layouts.admin');
    }
}
