<?php

namespace App\Livewire\Admin\Product;

use App\Models\Product;
use App\Models\ProductDetail;
use App\Models\Storage;
use Illuminate\Support\Facades\DB;
use Livewire\Component;
use Livewire\WithPagination;
use WireUi\Traits\WireUiActions;

class Index extends Component
{
    use WireUiActions, WithPagination;

    public function deleteProduct($product_id)
    {
        try {
            // Begin a transaction
            DB::beginTransaction();

            // Retrieve the product
            $product = Product::find($product_id);
            // Delete associated product details
            ProductDetail::where('product_id', $product->id)->delete();
            Storage::where('table_id', $product->id)->delete();

            // Delete the product
            $product->delete();

            // Commit the transaction
            DB::commit();

            $this->notification()->success(
                'Product Deleted Successfully'
            );

            return redirect()->to(route('products.index'));
        } catch (\Throwable $th) {
            $this->notification()->error(
                $th->getMessage()
            );
        }
    }

    public function updateStatus($product_id): void
    {
        try {
            $product = Product::where('id', $product_id)->first();
            $product->status = ! $product->status;
            $product->save();
            $this->notification()->success(
                'Product Status Updated Successfully'
            );
        } catch (\Throwable $th) {
            $this->notification()->error(
                $th->getMessage()
            );
        }
    }

    public function render()
    {
        $products = Product::paginate(10);

        return view('livewire.admin.product.index', ['products' => $products])->layout('components.layouts.admin');
    }
}
