<?php

namespace App\Livewire\Admin\ProductCategory;

use App\Models\ProductCategory;
use Livewire\Component;

class Edit extends Component
{
    public $categoryId;
    public $name;
    public $description;

    public function mount($id)
    {
        // Load the category data
        $category = ProductCategory::findOrFail($id);

        $this->categoryId = $category->id;
        $this->name = $category->name;
        $this->description = $category->description;
    }
    public function update()
    {
        // Validate input
        $this->validate([
            'name' => 'required|string|max:255',
            'description' => 'required',
        ]);

        // Update the category
        $category = ProductCategory::findOrFail($this->categoryId);
        $category->update([
            'name' => $this->name,
            'description' => $this->description,
        ]);

        // Success message (optional)
        session()->flash('message', 'Category updated successfully.');

        // Redirect to category listing or other desired page
        return redirect()->route('category.index');
    }
    public function render()
    {
        return view('livewire.admin.product-category.edit')->layout('components.layouts.admin');
    }
}
