<?php

namespace App\Livewire\Admin\ProductSubCategory;

use App\Models\ProductCategory;
use App\Models\SubCategory;
use Illuminate\Support\Facades\Storage;
use Livewire\WithFileUploads;
use Livewire\Component;

class Edit extends Component
{
    use WithFileUploads;
    public $category_id;
    public $name;
    public $description;
    public $photo; // New photo being uploaded
    public $currentPhoto; // Existing photo path
    public $id;

    public function mount($id)
    {
        $this->id = $id;
        // Load the category data
        $category = SubCategory::findOrFail($id);
        $this->category_id = $category->category_id;
        $this->name = $category->name;
        $this->description = $category->description;
        $this->currentPhoto = $category->photo;
    }
    public function update()
    {
        // Validate input
        $this->validate([
            'name' => 'required|string|max:255',
            'description' => 'required',
        ]);

        // Update the category
        $subcategory = SubCategory::findOrFail($this->id);

        if ($this->photo) {
            $photoPath = $this->photo->store('photos', 'public');

            // Optionally delete the old photo
            if ($this->currentPhoto && Storage::disk('public')->exists($this->currentPhoto)) {
                Storage::disk('public')->delete($this->currentPhoto);
            }
        }
        $subcategory->update([
            'name' => $this->name,
            'description' => $this->description,
            'category_id' => $this->category_id,
            'photo' => $photoPath
        ]);

        // Success message (optional)
        session()->flash('message', 'Category updated successfully.');

        // Redirect to category listing or other desired page
        return redirect()->route('subcategory.index');
    }
    public function render()
    {
        $categories = ProductCategory::all();
        return view('livewire.admin.product-sub-category.edit', ['categories' => $categories])->layout('components.layouts.admin');
    }
}
