<?php

namespace App\Livewire\Product;

use App\Models\Product;
use App\Models\ProductDetail as ProductDetailModel;
use App\Models\Wishlist;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Auth;
use Livewire\Component;

class ProductDetail extends Component
{
    public string $slug;

    public ?Product $product;

    //public ?ProductDetailModel $productDetailModel;

    public $allProducts;

    public $wishlistProducts;

    public $user;

    public $selectedDetailId;

    public $price;

    public $actualPrice;

    public function __construct()
    {
        $this->user = Auth::user();
    }

    public function mount(): void
    {

        // $products = config('nutsons.products');
        // $this->product = collect(array_values(Arr::where($products, function ($value) {
        //     return $value['slug'] === $this->slug;
        // })))->first();

        $this->product = Product::where('slug', $this->slug)->with('packagingDetail')->first();
        $this->selectedDetailId = $this->product->packagingDetail->first()->id ?? null;
        $this->updatePrice();

        $this->allProducts = Product::where('status', 1)->orderBy('id', 'DESC')->take(3)->get();

        if (isset($this->user)) {
            $this->wishlistProducts = Wishlist::where('user_id', $this->user->id)
                ->pluck('product_id')
                ->toArray();
        }

        if (empty($this->product)) {
            $this->redirect('/');
        }
    }

    public function changePrice()
    {
        $this->updatePrice();
    }

    protected function updatePrice()
    {
        if ($this->selectedDetailId) {
            $detail = $this->product->packagingDetail->find($this->selectedDetailId);
            $this->price = $detail->discount_price ?? 0;
            $this->actualPrice = $detail->actual_price ?? 0;
        } else {
            $this->price = 0;
            $this->actualPrice = 0;
        }
    }

    public function render()
    {

        return view('livewire.product.product-detail')
            ->layout('components.layouts.main');
    }
}
