<?php

namespace App\Livewire;

use Livewire\Component;
use App\Models\User;


class Users extends Component
{
    public $users;
    public $name, $email, $selectedUserId;
    public $isEditing = false;

    // Mount method to load users
    public function mount()
    {
        $this->users = User::all();
    }
      // Select user to edit
    public function selectUser($id)
    {
        $this->isEditing = true;
        $user = User::findOrFail($id);
        $this->selectedUserId = $id;
        $this->name = $user->name;
        $this->email = $user->email;
    }
      // Update user information
    public function updateUser()
    {
        $this->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|max:255',
        ]);

        $user = User::find($this->selectedUserId);
        $user->update([
            'name' => $this->name,
            'email' => $this->email,
        ]);

        // Reset form and refresh user list
        $this->resetForm();
        $this->users = User::all();
    }

    // Reset form after update
    public function resetForm()
    {
        $this->isEditing = false;
        $this->name = '';
        $this->email = '';
        $this->selectedUserId = null;
    }
    public function render()
    {
        return view('livewire.user')->layout('components.layouts.admin');
    }
}
