<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class CampaignPerformanceMetric extends Model
{
    use HasFactory;

    protected $table = 'campaign_performance_metrics'; // Explicitly defining table name

    protected $fillable = [
        'campaign_id',
        'impressions',
        'clicks',
        'cost',
        'sales1d',
        'sales7d',
        'sales14d',
        'sales30d',
        'attributed_sales_same_sku30d',
        'attributed_sales_same_sku14d',
        'attributed_sales_same_sku7d',
        'attributed_sales_same_sku1d',
        'start_date',
        'end_date',
    ];

    public function ebayCampaign()
    {
        return $this->belongsTo(Ebay_Campaigns::class, 'campaign_id', 'campaign_id');
    }
    // ROAS (Return on Ad Spend) = Total Revenue / Total Ad Spend (Cost)
    public function getRoasAttribute()
    {
        return $this->cost > 0 ? round($this->sales1d / $this->cost, 2) : 0;
    }

    // ACOS (Advertising Cost of Sales) = (Total Ad Spend / Total Revenue) * 100
    public function getAcosAttribute()
    {
        return $this->sales30d > 0 ? round(($this->cost / $this->sales1d) * 100, 2) : 0;
    }

    // CPC (Cost Per Click) = Total Cost / Total Clicks
    public function getCpcAttribute()
    {
        return $this->clicks > 0 ? round($this->cost / $this->clicks, 2) : 0;
    }

    // CTR (Click-Through Rate) = (Total Clicks / Total Impressions) * 100
    public function getCtrAttribute()
    {
        return $this->impressions > 0 ? round(($this->clicks / $this->impressions) * 100, 2) : 0;
    }

    // CPI (Cost Per Impression) = Total Cost / Total Impressions
    public function getCpiAttribute()
    {
        return $this->impressions > 0 ? round($this->cost / $this->impressions, 6) : 0;
    }

    // CVR (Conversion Rate) = (Total Sales / Total Clicks) * 100
    public function getCvrAttribute()
    {
        return $this->clicks > 0 ? round(($this->sales30d / $this->clicks) * 100, 2) : 0;
    }

    
}
