<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Ebay_Campaigns extends Model
{
    //
     use HasFactory;

    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'ebay_campaigns';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'campaign_id',
        'campaign_name',
        'marketplace_id',
        'campaign_status',
        'start_date',
        'end_date',
        'campaign_targeting_type',
        'funding_model',
        'bidding_strategy',
        'daily_budget_value',
        'daily_budget_currency',
        'daily_budget_status',
        'channels',
        'source',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array
     */
    protected $casts = [
        'channels' => 'array', // Cast channels to an array
        'start_date' => 'datetime', // Cast start_date to a datetime instance
        'end_date' => 'datetime', // Cast end_date to a datetime instance
    ];

    /**
     * Accessor for the full daily budget (value and currency).
     *
     * @return string
     */
    public function getDailyBudgetAttribute(): string
    {
        return $this->daily_budget_value . ' ' . $this->daily_budget_currency;
    }

    /**
     * Mutator for setting the daily budget.
     *
     * @param string $value
     * @return void
     */
    public function setDailyBudgetAttribute(string $value): void
    {
        $parts = explode(' ', $value);
        $this->attributes['daily_budget_value'] = $parts[0];
        $this->attributes['daily_budget_currency'] = $parts[1] ?? 'USD'; // Default to USD if currency is not provided
    }

    /**
     * Accessor for formatted start date.
     *
     * @return string
     */
    public function getFormattedStartDateAttribute(): string
    {
        return $this->start_date->format('Y-m-d H:i:s');
    }

    /**
     * Accessor for formatted end date.
     *
     * @return string|null
     */
    public function getFormattedEndDateAttribute(): ?string
    {
        return $this->end_date ? $this->end_date->format('Y-m-d H:i:s') : null;
    }

     // Define the relationship to CampaignKeyword
    public function keywords()
    {
        return $this->hasMany(CampaignKeyword::class, 'campaign_id', 'campaign_id');
    }
    public function adGroups()
    {
        return $this->hasMany(AdGroup::class,'campaign_id','campaign_id');
    }

    public function performanceMetrics()
    {
        return $this->hasMany(CampaignPerformanceMetric::class, 'campaign_id', 'campaign_id');
    }

}
