<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Database\Eloquent\SoftDeletes;
use Livewire\Features\SupportFileUploads\TemporaryUploadedFile;

/**
 * @property int $id
 * @property int $user_id
 * @property string|null $product_name_en
 * @property string|null $product_name_ar
 * @property string|null $product_name_tr
 * @property string|null $product_sku
 * @property float|null $price
 * @property int|null $stock
 * @property string|null $description_en
 * @property string|null $description_ar
 * @property string|null $description_tr
 * @property string|null $main_image
 * @property string|null $other_images
 * @property string|null $health_benefits_en
 * @property string|null $health_benefits_ar
 * @property string|null $health_benefits_tr
 * @property string|null $way_add_to_your_diet_en
 * @property string|null $way_add_to_your_diet_ar
 * @property string|null $way_add_to_your_diet_tr
 * @property string|null $how_to_store_en
 * @property string|null $how_to_store_ar
 * @property string|null $how_to_store_tr
 * @property bool|null $status
 */
class Product extends Model
{
    use HasFactory, SoftDeletes;

    protected $fillable = [
        'user_id',
        'name',
        'description',
        'status',
        'category_id',
        'main_category'
    ];
    public function otherImages(): HasMany
    {
        return $this->hasMany(Storage::class, 'table_id', 'id')
            ->where('table_type', 'product_other_image');
    }

    public function mainImage(): HasOne
    {
        return $this->hasOne(Storage::class, 'table_id', 'id')
            ->where('table_type', 'product_main_image');
    }

    public function packagingDetail(): HasOne
    {
        return $this->hasOne(ProductDetail::class);
    }

    public function cartsItem()
    {
        return $this->hasMany(Cart::class, 'product_id');
    }

    public function wishList()
    {
        return $this->hasMany(Wishlist::class, 'product_id');
    }

    public function isTemporaryUploadedFile($photo): bool
    {
        if ($photo instanceof TemporaryUploadedFile) {
            return true;
        }

        return false;
    }
    // A Product belongs to a SubCategory
    public function subCategory()
    {
        return $this->belongsTo(SubCategory::class, 'category_id', 'id');
    }
    // A Product indirectly belongs to a Category through SubCategory
    public function category()
    {
        return $this->hasOneThrough(ProductCategory::class, SubCategory::class, 'id', 'id', 'category_id', 'category_id');
    }
}
