@extends('front.main')
@push('style')
    <style>
        body {
            font-family: 'Poppins', sans-serif;
            background-color: #fdf7e6;
            margin: 0;
            padding: 0;
        }
        .header {
            background-color: #2d4739;
            padding: 20px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            color: white;
        }
        .header h1 {
            font-size: 24px;
            margin: 0;
        }
        .header a {
            color: white;
            text-decoration: none;
            font-weight: 600;
        }
        .container {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
            text-align: center;
        }
        .container h2 {
            font-size: 32px;
            color: #d48844;
        }
        .order-card {
            background-color: #e0d3b8;
            padding: 15px;
            border-radius: 10px;
            box-shadow: 0px 4px 8px rgba(0, 0, 0, 0.1);
            margin-bottom: 20px;
            text-align: left;
            font-size: 14px;
        }
        .order-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            font-weight: bold;
            color: #2d4739;
        }
        .order-items {
            margin-top: 10px;
        }
        .order-item {
            display: flex;
            align-items: center;
            margin-top: 10px;
        }
        .item-image {
            width: 60px;
            height: 60px;
            border-radius: 5px;
            margin-right: 15px;
        }
        .item-details {
            flex-grow: 1;
        }
        .item-name {
            font-size: 16px;
            font-weight: 600;
            color: #2d4739;
        }
        .item-price {
            font-size: 14px;
            color: #8a7d65;
        }
        .status {
            color: #d48844;
            font-weight: bold;
            margin-top: 10px;
            font-size: 14px;
        }

        .order-status-amount {
            display: flex;
            justify-content: space-between; /* Adjust spacing as needed */
            margin-top: 10px; /* Optional spacing */
        }

        .status, .amount {
            margin: 0; /* Reset margins */
        }
    </style>
@endpush
@section('content')
<div class="container">
    <h2>My Orders</h2>
    @foreach($orders as $order)
    <!-- Order Card 1 -->
    <div class="order-card">
        <div class="order-header">
            <div>Order {{ $order->payment_reference }}</div>
            <div>Date: {{$order->created_at->format('D - d F, Y') }}</div>
        </div>
        <div class="order-items">
            @foreach($order->orderDetails as $item)
                <div class="order-item">
                    <img src="{{ asset('storage/' .  $item->product->mainImage->file_path ?? null) }}" alt="Diamond" class="item-image">
                    <div class="item-details">
                        <div class="item-name">{{ $item->product->name }}</div>
                        <div class="item-price">${{ number_format($item->productDetails->price) }}</div>
                    </div>
                    <div class="item-quantity">Qty: {{ $item->quantity }}</div>
                </div>
            @endforeach
        </div>
        <div class="order-status-amount">
            <div class="status">Status: {{ $order->order_status }}</div>
            <div class="amount"><b>Total:</b> ${{ number_format($order->payment->amount) }}</div>
        </div>
    </div>
    @endforeach
</div>
@endsection
