<div class="w-full p-6 mx-auto">
    <div class="rounded-xl border dark:border-gray-700 border-gray-300 bg-white p-4 py-3 sm:px-6 sm:py-4 xl:px-7">
        <h2 class="text-lg font-bold mb-4">Edit Category</h2>
        <form wire:submit.prevent="update" class="p-6">
            <div class="mb-4">
                <label for="name" class="block font-medium text-sm text-gray-700">Category Name</label>
                <input 
                    type="text" 
                    wire:model="name" 
                    id="name" 
                    class="block mt-1 w-full border-gray-300 rounded-md shadow-sm focus:border-green-300 focus:ring focus:ring-green-200 focus:ring-opacity-50">
                @error('name') <span class="text-red-500 text-sm">{{ $message }}</span> @enderror
            </div>
            <div class="w-full">
                <label for="category_id" class="font-medium text-sm dark:text-white text-gray-800">Sub Category Name</label>
                <select wire:model="category_id" name="category_id" wire:model="category_id" id="category_id"  class="text-sm py-3 px-5 border dark:border-gray-700 border-gray-300 rounded-lg w-full outline-0 focus:outline-none focus:border-green bg-transparent">
                    <option value="">--Select Category--</option>
                    @foreach($categories as $category)
                        <option value="{{ $category->id }}">{{ $category->name }}</option>
                    @endforeach
                </select>
                <x-input-error :messages="$errors->get('category_id')" class="mt-2" />
            </div>
            <div class="w-full">
                <label for="productname" class="font-medium text-sm dark:text-white text-gray-800 mb-3">Image</label>
                <label class="relative flex flex-col items-center text-sm py-3 px-5 border dark:border-gray-700 border-gray-300 rounded-lg w-full outline-0 focus:outline-none focus:border-green bg-transparent cursor-pointer">
                    <svg class="w-8 h-8" fill="#66b749" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20">
                        <path d="M16.88 9.1A4 4 0 0 1 16 17H5a5 5 0 0 1-1-9.9V7a3 3 0 0 1 4.52-2.59A4.98 4.98 0 0 1 17 8c0 .38-.04.74-.12 1.1zM11 11h3l-4-4-4 4h3v3h2v-3z" />
                    </svg>
                    <span class="mt-2 text-base leading-normal text-gray-600">Image</span>
                    <input wire:model="photo" name="photo" type='file' class="absolute w-full h-full opacity-0"/>
                </label>
                @if ($currentPhoto)
                    <div class="relative w-32 h-32 overflow-hidden">
                        <i class="fa-solid fa-xmark absolute top-1 right-1 text-gray-300 hover:text-red-500"></i>
                        <img src="{{asset('storage/' . $currentPhoto)}}" alt="img" class="w-full">
                    </div>
                @endif
            </div>

            <div class="mb-4">
                <label for="description" class="block font-medium text-sm text-gray-700">Description</label>
                <textarea 
                    wire:model="description" 
                    id="description" 
                    class="block mt-1 w-full border-gray-300 rounded-md shadow-sm focus:border-green-300 focus:ring focus:ring-green-200 focus:ring-opacity-50" 
                    rows="5"></textarea>
                @error('description') <span class="text-red-500 text-sm">{{ $message }}</span> @enderror
            </div>

            <div class="flex items-center justify-end">
                <a href="{{ route('category.index') }}" class="btn-default btn-secondary mr-3">Cancel</a>
                <button type="submit" class="btn-default btn-primary">Update Category</button>
            </div>
        </form>
    </div>
</div>