<?php

use App\Livewire\Forms\LoginForm;
use Illuminate\Support\Facades\Session;
use Livewire\Attributes\Layout;
use Livewire\Volt\Component;

new #[Layout('layouts.guest')] class extends Component
{
    public LoginForm $form;

    /**
     * Handle an incoming authentication request.
     */
    public function login(): void
    {
        $this->validate();
        if (!auth()->attempt(['email' => $this->form->email, 'password' => $this->form->password])) {
            // Flash an error message if authentication fails
            session()->put('status','Invalid login credentials.');
        }
        Session::regenerate();
        session()->flash('reload', true);

        
        $this->redirect(route('dashboard'));

        // $this->redirectIntended(default: route('dashboard', absolute: false), navigate: true);
    }
}; ?>

<x-guest-layout>
    <div class="bg-[#FEFAE0] text-gray-800">
     <div class="flex items-center justify-center h-screen">
        <div class="relative flex items-center justify-center w-full max-w-md p-6 rounded-lg shadow-lg bg-gradient-to-br from-[#B2E1D7] to-[#D6F4E2]">
            <div class="relative w-full p-8 bg-white rounded-lg shadow-md z-10" style="display: flex;flex-direction: column;align-items: center;">
            <img src="{{ asset('assets/images/Geology-04.png') }}" alt="Company Logo" class="logo"> <!-- Replace with your logo path -->
                <x-auth-session-status class="mb-4" :status="session('status')" />

                <h2 class="text-[#052D25] text-3xl mb-2">Welcome Back</h2>
                <p class="text-gray-600 mb-6">Log in to your account to continue shopping</p>
                <form wire:submit="login">
                    {{-- <label for="email" class="block font-bold mb-2 text-left text-[#052D25]">Email Address</label> --}}
                    <x-input-label for="email" :value="__('Email')" class="block font-bold mb-2 text-left text-[#052D25]" />

                    {{-- <input type="email" id="email" name="email" placeholder="Enter your email" required class="w-full p-3 mb-5 border-2 border-[#052D25] rounded-lg focus:border-[#4E54C8] focus:outline-none"> --}}
                    <x-text-input wire:model="form.email" id="email" class="w-full p-3 mb-5 border-2 border-[#052D25] rounded-lg focus:border-[#4E54C8] focus:outline-none" type="email" name="email" required autofocus autocomplete="username" />
                    <x-input-error :messages="$errors->get('form.email')" class="mt-2" />

                    <x-input-label for="password" :value="__('Password')" />
                    <x-text-input wire:model="form.password" id="password" class="w-full p-3 mb-5 border-2 border-[#052D25] rounded-lg focus:border-[#4E54C8] focus:outline-none"
                            type="password"
                            name="password"
                            required autocomplete="current-password" />
                    {{-- <input type="password" id="password" name="password" placeholder="Enter your password" required class="w-full p-3 mb-5 border-2 border-[#052D25] rounded-lg focus:border-[#4E54C8] focus:outline-none"> --}}
                    <x-primary-button class="w-full p-3 font-bold text-white bg-[#052D25] rounded-lg transition duration-300 ease-in-out transform hover:bg-[#3a41c8] hover:translate-y-[-2px] flex justify-center items-center">
                        {{ __('Log in') }}
                    </x-primary-button>
                    {{-- <button type="submit" class="w-full p-3 font-bold text-white bg-[#052D25] rounded-lg transition duration-300 ease-in-out transform hover:bg-[#3a41c8] hover:translate-y-[-2px]">Log In</button> --}}
                    
                    <div class="flex justify-between mt-4 text-sm text-[#052D25]">
                        <a href="#" class="transition duration-300 ease-in-out hover:text-[#3a41c8]">Forgot Password?</a>
                        <a href="#" class="transition duration-300 ease-in-out hover:text-[#3a41c8]">Create an Account</a>
                    </div>
                </form>
            </div>
        </div>
    </div>
</x-guest-layout>

{{-- <div>

    <!-- Session Status -->
    <x-auth-session-status class="mb-4" :status="session('status')" />

    <form wire:submit="login">
        <!-- Email Address -->
        <div>
            <x-input-label for="email" :value="__('Email')" />
            <x-text-input wire:model="form.email" id="email" class="block mt-1 w-full" type="email" name="email" required autofocus autocomplete="username" />
            <x-input-error :messages="$errors->get('form.email')" class="mt-2" />
        </div>

        <!-- Password -->
        <div class="mt-4">
            <x-input-label for="password" :value="__('Password')" />

            <x-text-input wire:model="form.password" id="password" class="block mt-1 w-full"
                            type="password"
                            name="password"
                            required autocomplete="current-password" />

            <x-input-error :messages="$errors->get('form.password')" class="mt-2" />
        </div>

        <!-- Remember Me -->
        <div class="block mt-4">
            <label for="remember" class="inline-flex items-center">
                <input wire:model="form.remember" id="remember" type="checkbox" class="rounded dark:bg-gray-900 border-gray-300 dark:border-gray-700 text-indigo-600 shadow-sm focus:ring-indigo-500 dark:focus:ring-indigo-600 dark:focus:ring-offset-gray-800" name="remember">
                <span class="ms-2 text-sm text-gray-600 dark:text-gray-400">{{ __('Remember me') }}</span>
            </label>
        </div>

        <div class="flex items-center justify-end mt-4">
            @if (Route::has('password.request'))
                <a class="underline text-sm text-gray-600 dark:text-gray-400 hover:text-gray-900 dark:hover:text-gray-100 rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 dark:focus:ring-offset-gray-800" href="{{ route('password.request') }}" wire:navigate>
                    {{ __('Forgot your password?') }}
                </a>
            @endif

            <x-primary-button class="ms-3">
                {{ __('Log in') }}
            </x-primary-button>
        </div>
    </form>
</div> --}}
