<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>Order Confirmation</title>
    <style>
        body {
            font-family: 'Helvetica Neue', Arial, sans-serif;
            background-color: #f4f4f4;
            color: #333;
            margin: 0;
            padding: 0;
        }
        .email-container {
            width: 100%;
            max-width: 700px;
            margin: 0 auto;
            background-color: #ffffff;
            border-radius: 10px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            overflow: hidden;
        }
        .email-header {
            background-color: #052D25;
            padding: 20px;
            text-align: center;
        }
        .email-header img {
            max-width: 160px;
        }
        .email-header h1 {
            color: #ffffff;
            font-size: 28px;
            margin: 0;
        }
        .email-body {
            padding: 30px;
            color: #333;
        }
        .email-body h2 {
            color: #0a1e5e;
            font-size: 22px;
            margin-bottom: 20px;
        }
        .section {
            margin-bottom: 30px;
            padding: 20px;
            background-color: #f9f9f9;
            border-radius: 8px;
        }
        .section-title {
            color: #0a1e5e;
            font-size: 18px;
            margin-bottom: 15px;
            font-weight: bold;
            border-bottom: 2px solid #0a1e5e;
            padding-bottom: 8px;
        }
        .details-table {
            width: 100%;
            border-collapse: collapse;
        }
        .details-table th, .details-table td {
            padding: 12px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }
        .details-table th {
            color: #0a1e5e;
            font-weight: bold;
            background-color: #f2f2f2;
        }
        .details-table td {
            color: #555;
        }
        .details-table td:last-child {
            font-weight: bold;
        }
        .email-footer {
            background-color: #052D25;
            padding: 20px;
            text-align: center;
            color: #fff;
        }
        .email-footer p {
            margin: 0;
            font-size: 14px;
        }
        .email-footer a {
            display: inline-block;
            padding: 10px 20px;
            background-color: #e94560;
            color: #fff;
            text-decoration: none;
            border-radius: 6px;
            margin-top: 10px;
        }
        .button:hover {
            background-color: #d03a52;
        }
    </style>
</head>
<body>
    <div class="email-container">
        <!-- Header -->
        <div class="email-header">
            <img src="https://geologys.com/assets/images/Geology-03.png" alt="Geology Logo">
            <h1>Order Confirmed</h1>
        </div>

        <!-- Body -->
        <div class="email-body">
            <!-- Order Details Section -->
            <div class="section">
                <h2 class="section-title">Order Details</h2>
                <table class="details-table">
                    <tr>
                        <th>Order ID:</th>
                        <td>{{ $order->payment_reference }}</td>
                    </tr>
                    <tr>
                        <th>Order Date:</th>
                        <td>{{$order->created_at->format('D - d F, Y') }}</td>
                    </tr>
                    <tr>
                        <th>Status:</th>
                        <td><strong style="color: #28a745;">{{ $order->order_status }}</strong></td>
                    </tr>
                </table>
            </div>

            <!-- Customer Information Section -->
            <div class="section">
                <h2 class="section-title">Customer Information</h2>
                <table class="details-table">
                    <tr>
                        <th>Name:</th>
                        <td>{{ $order['billingAddress']->first_name }}&nbsp;{{ $order['billingAddress']->last_name }}</td>
                    </tr>
                    <tr>
                        <th>Email:</th>
                        <td>{{ $order['billingAddress']->email }}</td>
                    </tr>
                    <tr>
                        <th>Phone:</th>
                        <td>{{ $order['billingAddress']->contact }}</td>
                    </tr>
                    <tr>
                        <th>Shipping Address:</th>
                        <td>{{ $order['billingAddress']->address }}<br>{{ $order['billingAddress']->city }}, {{ $order['billingAddress']->state }}, {{ $order['billingAddress']->country }} <br> {{ $order['billingAddress']->pincode }}</td>
                    </tr>
                </table>
            </div>

            <!-- Product Information Section -->
            <div class="section">
                <h2 class="section-title">Product Information</h2>
                <table class="details-table">
                    <tr>
                        <th>#</th>
                        <th>Product</th>
                        <th>Style</th>
                        <th>Quantity</th>
                        <th>Price</th>
                    </tr>
                    @foreach($order->orderDetails as $item)
                        <tr>
                            <td>{{ $loop->iteration }}</td>
                            <td>{{ $item->product->name }}</td>
                            <td>{{ $item->productDetails->style }} <small>({{ $item->productDetails->size }} carats)</td>
                            <td>{{ $item->quantity }}</td>
                            <td>${{ number_format($item->quantity * $item->productDetails->price) }}</td>
                        </tr>
                    @endforeach
                   
                </table>
            </div>

            <!-- Payment Information Section -->
            <div class="section">
                <h2 class="section-title">Payment Information</h2>
                <table class="details-table">
                    <tr>
                        <th>Transaction ID:</th>
                        <td>{{ $order->payment->payment_id }}</td>
                    </tr>
                    <tr>
                        <th>Amount:</th>
                        <td>${{ number_format($order->payment->amount) }}</td>
                    </tr>
                    <tr>
                        <th>Payment Status:</th>
                        <td><strong style="color: #28a745;">
                            @if($order->payment->payment_status=="[capture-received]")
                                Paid
                            @else
                                Pending 
                            @endif
                            </strong>
                        </td>
                    </tr>
                    <tr>
                        <th>Payment Method:</th>
                        <td>{{ $order->payment->payment_method }}</td>
                    </tr>
                </table>
            </div>
        </div>

        <!-- Footer -->
        <div class="email-footer">
            <p>Thank you for shopping with Geology! We hope to see you again soon.</p>
            <a href="your-website-url-here" class="button">Back to Website</a>
        </div>
    </div>
</body>
</html>
{{-- <!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>Order Confirmation</title>
    <style>
        body {
            font-family: 'Helvetica Neue', Arial, sans-serif;
            background-color: #f4f4f4;
            color: #333;
            margin: 0;
            padding: 0;
        }
        .email-container {
            max-width: 650px;
            margin: 0 auto;
            background-color: #ffffff;
            border-radius: 10px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            overflow: hidden;
        }
        .email-header {
            background-color: #0a1e5e;
            padding: 15px;
            text-align: center;
        }
        .email-header img {
            max-width: 120px;
        }
        .email-body {
            padding: 20px;
            color: #333;
        }
        .section {
            margin-bottom: 20px;
            padding: 15px;
            background-color: #f9f9f9;
            border-radius: 8px;
        }
        .details-table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 10px;
        }
        .details-table th, .details-table td {
            padding: 8px;
            text-align: left;
        }
        .details-table th {
            color: #0a1e5e;
            font-weight: bold;
        }
        .details-table td {
            color: #555;
        }
        .email-footer {
            background-color: #0a1e5e;
            padding: 15px;
            text-align: center;
            color: #fff;
        }
    </style>
</head>
<body>
    <div class="email-container">
        <!-- Header -->
        <div class="email-header">
            <img src="{{ asset('assets/images/Geology-03.png') }}" alt="Geology Logo">
        </div>

        <!-- Body -->
        <div class="email-body">
            <div class="section">
                <strong>Order ID:</strong> ORDER-670FACBAA5023<br>
                <strong>Date:</strong> Thu, 17 October 2024<br>
                <strong>Status:</strong> <span style="color: #28a745;">Confirmed</span>
            </div>
            <div class="section">
                <strong>Customer:</strong> Dev Patel<br>
                <strong>Email:</strong> l8m7g@nynna.com
            </div>
            <div class="section">
                <table class="details-table">
                    <tr>
                        <th>Product</th>
                        <th>Qty</th>
                        <th>Price</th>
                    </tr>
                    <tr>
                        <td>Sapphire (22 carats)</td>
                        <td>1</td>
                        <td>$200</td>
                    </tr>
                    <tr>
                        <td>Diamond (22 carats)</td>
                        <td>3</td>
                        <td>$45,000</td>
                    </tr>
                </table>
            </div>
            <div class="section">
                <strong>Total:</strong> $45,200<br>
                <strong>Payment:</strong> Paid (Card)
            </div>
        </div>

        <!-- Footer -->
        <div class="email-footer">
            <p>Thank you for shopping with Geology!</p>
        </div>
    </div>
</body>
</html> --}}