<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>Payment Receipt Confirmation</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f4f4f4;
            color: #333;
            margin: 0;
            padding: 0;
        }
        .email-container {
            max-width: 650px;
            margin: 0 auto;
            background-color: #ffffff;
            border-radius: 10px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            overflow: hidden;
        }
        .email-header {
            background-color: #052D25;
            padding: 20px;
            text-align: center;
        }
        .email-header img {
            max-width: 150px;
        }
        .email-body {
            padding: 20px;
            color: #333;
        }
        .section {
            margin-bottom: 20px;
            padding: 15px;
            background-color: #f9f9f9;
            border-radius: 8px;
        }
        .details-table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 10px;
        }
        .details-table th, .details-table td {
            padding: 8px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }
        .details-table th {
            color: #0a1e5e;
            font-weight: bold;
        }
        .details-table td {
            color: #555;
        }
        .email-footer {
            background-color: #052D25;
            padding: 15px;
            text-align: center;
            color: #fff;
        }
        .summary {
            font-weight: bold;
            font-size: 1.2em;
        }
        .status-paid {
            color: #28a745;
        }
    </style>
</head>
<body>
    <div class="email-container">
        <!-- Header -->
        <div class="email-header">
            <img src="https://geologys.com/assets/images/Geology-03.png" alt="Geology">
        </div>

        <!-- Body -->
        <div class="email-body">
            <div class="section">
                <strong>Invoice Number:</strong> {{ $payment->payment_id }}<br>
                <strong>Invoice Date:</strong> {{ $payment->created_at->format('D - d F, Y') }}<br>
                <strong>Payment Status:</strong> <span class="status-paid"> 
                    @if($payment->payment_status=="[capture-received]")
                        Paid
                    @else
                        Pending
                    @endif
                </span>
            </div>
            <div class="section">
                <strong>Bill to:</strong> {{ $payment->billingAddress->first_name }}&nbsp;{{ $payment->billingAddress->last_name }}<br>
                <strong>Email:</strong> {{ $payment->billingAddress->email }}<br>
                <strong>Address:</strong> {{ $payment->billingAddress->city }}, {{ $payment->billingAddress->state }}, {{ $payment->billingAddress->country }}-{{ $payment->billingAddress->pincode }}
            </div>
            <div class="section">
                <table class="details-table">
                    <tr>
                        <th>Items</th>
                        <th>Qty</th>
                        <th>Price</th>
                        <th>Amount</th>
                    </tr>
                    @foreach($payment->orderDetails as $item)
                        <tr>
                            <td>{{ $item->product->name }}({{ $item->productDetails->style }})</td>
                            <td>{{ $item->quantity }}</td>
                            <td>${{ number_format($item->productDetails->price) }}</td>
                            <td>${{ number_format($item->productDetails->price * $item->quantity) }}</td>
                        </tr>
                    @endforeach
                </table>
            </div>
            <div class="section">
                <strong class="summary">Subtotal:</strong> ${{ number_format($payment->amount) }}<br>
                <strong class="summary">Total:</strong> ${{ number_format($payment->amount) }}
            </div>
        </div>

        <!-- Footer -->
        <div class="email-footer">
            <p>Thank you for your payment with Geology!</p>
        </div>
    </div>
</body>
</html>