<x-layouts.main>

    <!-- start breadcrumb section -->
    <div class="breadcrumb">
        <div class="max-w-screen-2xl mx-auto px-4">
            <h2 class="mb-0 font-bold">@lang('messages.your') @lang('messages.cart')</h2>
        </div>
    </div>
    <div class="cart-page">
        <div class="max-w-screen-2xl mx-auto px-4 default-padding">
            <div class="flex flex-col md:flex-row gap-4">
                <div class="md:w-2/3">
                    @foreach ($cartItems as $key => $cartItem)
                    <div class="cart-product relative justify-between mb-6 rounded-lg border bg-white p-6 shadow-md sm:flex sm:justify-start">
                        <div class="flex items-center sm:flex-row flex-col w-full">
                            <img src="{{ asset('assets/images/almond.png')}}" alt="product-image" class="rounded-lg px-4 py-2 bg-slate-200" width="100"/>
                            <div class="ml-4 sm:flex sm:w-full sm:justify-between mr-4 flex-wrap space-y-3">
                                <div class="sm:mt-0 mt-6">
                                    <h2 class="text-xl font-bold text-gray-900">{{ $cartItem->productsItem->{'product_name_'.Lang::locale()} }}</h2>
                                    <p class="mt-1 text-sm text-gray-700">{{ $cartItem->productsDetailsItem->weight.' '.$cartItem->productsDetailsItem->mass }}</p>
                                </div>
                                <div class="flex justify-between flex-wrap sm:flex-row flex-col space-x-6 sm:gap-0 gap-3 cart-item">
                                    <div class="qty-container gap-1 quantity">
                                        <button class="qty-btn-minus btn-light update-cart minus" data-id="{{ $cartItem->id }}" data-type="decrement" type="button"><i class="fa fa-minus"></i></button>
                                        <input  id="quantity-{{ $cartItem->id }}" type="number" name="qty" value="{{ $cartItem->quantity }}" min="1" class="input-qty"/>
                                        <button class="qty-btn-plus btn-light update-cart plus" data-id="{{ $cartItem->id }}" data-type="increment" type="button"><i class="fa fa-plus"></i></button>
                                    </div>
                                    <div class="flex items-center sm:ml-6 ml-0">
                                        <p class="text-lg font-medium">$<span id="price-{{ $cartItem->id }}">{{ $cartItem->productsDetailsItem->discount_price }}</span></p>
                                        <p style="display: none;">Subtotal: $<span id="subtotal-{{ $cartItem->id }}">{{ $cartItem->productsDetailsItem->discount_price * $cartItem->quantity }}</span></p>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <form method="post" action="{{ route('cart.destroy' , $cartItem->id) }}" id="deleteCartItemForm">
                            {{ csrf_field() }}
                            @method('DELETE')
                            
                            <button type="submit" class="absolute top-1 ltr:right-3 rtl:left-3 hover:text-green">
                                <i class="fa-solid fa-xmark text-lg"></i>
                            </button>
                        </form>
                    </div>
                    @endforeach
                </div>
                <div class="md:w-1/3">
                    <div class="sticky top-5">
                        <div class="rounded-lg border bg-white p-6 shadow-md">
                            <h4 class="text-lg font-semibold tracking-wide">@lang('messages.shopping') @lang('messages.details')</h4>
                            <p class="text-gray-700">@lang('messages.you-have') 7 @lang('messages.items-in-your-cart')</p>
                            <hr class="mt-3 mb-6"/>
                            <div class="mb-2 flex justify-between">
                                <p class="text-gray-700">@lang('messages.subtotal')</p>
                                <p class="text-gray-700">$<span id="cart-sub-total">{{ number_format($totalAmount,2) }}</span></p>
                            </div>
                            <div class="mb-2 flex justify-between">
                                <p class="text-gray-700">@lang('messages.shipping')</p>
                                <p class="text-gray-700">$0.00</p>
                            </div>
                            <div class="mb-2 flex justify-between">
                                <p class="text-gray-700">@lang('messages.tax')</p>
                                <p class="text-gray-700">$0.00</p>
                            </div>
                            <div class="flex justify-between">
                                <p class="text-gray-700">@lang('messages.discount')</p>
                                <p class="text-gray-700">$0.00</p>
                            </div>
                            <hr class="my-4"/>
                            <div class="flex justify-between text-end">
                                <p class="text-lg font-bold">@lang('messages.total')</p>
                                <p class="mb-1 text-lg font-bold text-green">$<span id="cart-total">{{ number_format($totalAmount,2) }}</span></p>
                            </div>
                            <a href="{{ route('checkout.index') }}" class="btn-default btn-secondary mt-6 w-full">@lang('messages.continue')</a>
                        </div>
                        <div class="rounded-lg border bg-white p-6 shadow-md mt-6">
                            <h4 class="text-lg font-semibold tracking-wide">@lang('messages.coupen-code')</h4>
                            <p class="text-gray-700">@lang('messages.enter-code-to-get')</p>
                            <hr class="mt-3 mb-6"/>
                            <div class="input-group">
                                <input type="text" class="form-control me-0" placeholder="@lang('messages.coupen-code')">
                            </div>
                            <a href="javascript:void(0)" class="btn-default btn-secondary mt-6 w-full">@lang('messages.apply')</a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
    $(document).ready(function() {
        function updateSubtotal(itemId) {
            var quantityInput = $('#quantity-' + itemId);
            var quantity = parseInt(quantityInput.val());
            var price = parseFloat($('#price-' + itemId).text());
            
            var subtotal = quantity * price;

            $('#subtotal-' + itemId).text(subtotal.toFixed(2));
            
            updateCartTotal();
        }

        function updateCartTotal() {
            var total = 0;
            $('.cart-item').each(function() {
                var itemId = $(this).find('input').attr('id').split('-')[1];
                var subtotal = parseFloat($('#subtotal-' + itemId).text());
                
                total += subtotal;
            });
            $('#cart-sub-total').text(total.toFixed(2));
            $('#cart-total').text(total.toFixed(2));
        }

        $('.update-cart').click(function(e) {
            e.preventDefault();
            var itemId = $(this).data('id');
            var type = $(this).data('type');
            var quantityInput = $('#quantity-' + itemId);
            //var quantity = parseInt(quantityInput.val());
            //var price = parseFloat($('#price').text());
            //var subtotal = quantity * price;
            
            //console.log(quantity);
            var currentQuantity = parseInt(quantityInput.val());
            var newQuantity = type === 'increment' ? currentQuantity + 1 : currentQuantity - 1;
            
            if (newQuantity < 1) {
                return; // Or show an error message
            }
            
            $.ajax({
                type: 'PUT',
                url:"{{ route('cart.update', ['__id__']) }}".replace('__id__', itemId),
                data: {
                    _token: '{{ csrf_token() }}',
                    quantity: newQuantity
                },
                success: function(response) {
                    quantityInput.val(newQuantity);
                    updateSubtotal(itemId);
                },
                error: function(xhr) {
                    console.error('Error occurred: ', xhr.status, xhr.statusText);
                    console.error('Response: ', xhr.responseText);
                }
            });
        });
    });
</script>
</x-layouts.main>
